@@ -6,7 +6,7 @@
 #' @param Voronoi logical; \code{FALSE} (default) Displays a Voronoi type diagram using partial moment quadrants.
 #' @param type \code{NULL} (default) Controls the partitioning basis.  Set to \code{(type = "XONLY")} for X-axis based partitioning.  Defaults to \code{NULL} for both X and Y-axis partitioning.
 #' @param order integer; Number of partial moment quadrants to be generated.  \code{(order = "max")} will institute a perfect fit.
-#' @param max.obs.req integer; (4 default) Required observations per cluster where quadrants will not be further partitioned if observations are not greater than the entered value.  Reduces minimum number of necessary observations in a quadrant to 1 when \code{(max.obs.req = 1)}.
+#' @param max.obs.req integer; (8 default) Required observations per cluster where quadrants will not be further partitioned if observations are not greater than the entered value.  Reduces minimum number of necessary observations in a quadrant to 1 when \code{(max.obs.req = 1)}.
 #' @param min.obs.stop logical; \code{FALSE} (default) Stopping condition where quadrants will not be further partitioned if a single cluster contains less than the entered value of \code{max.obs.req}.
 #' @param noise.reduction the method of determing regression points options: ("mean", "median", "mode", "off"); \code{(noise.reduction = "median")} uses medians instead of means for partitions, while \code{(noise.reduction = "mode")} uses modes instead of means for partitions.  Defaults to \code{(noise.reduction = "mean")}, while \code{(noise.reduction = "off")} will partition quadrant to a single observation for a given \code{(order = ...)}.
 #' @return Returns:
@@ -40,8 +40,8 @@
 #' DT
 #' @export
 
-NNS.part = function(x, y, Voronoi = FALSE, type = NULL, order = NULL, max.obs.req = 4, min.obs.stop = FALSE, noise.reduction = "mean"){
-  if(is.null(max.obs.req)) max.obs.req=4
+NNS.part = function(x, y, Voronoi = FALSE, type = NULL, order = NULL, max.obs.req = 8, min.obs.stop = FALSE, noise.reduction = "mean"){
+  if(is.null(max.obs.req)) max.obs.req=8
 
   if(!is.null(order)){
     if(order == 0){
@@ -99,10 +99,11 @@ NNS.part = function(x, y, Voronoi = FALSE, type = NULL, order = NULL, max.obs.re
       if (l.PART <= max.obs.req && i >= 1) break
       max.obs.req.rows = PART[counts >= max.obs.req, which = TRUE]
       old.max.obs.req.rows = PART[old.counts >= max.obs.req, which = TRUE]
+      # Stop if diminishing returns
       if(max.obs.req > 0 && length(max.obs.req.rows) < length(old.max.obs.req.rows)) break
 
       #Segments for Voronoi...
-      if(Voronoi == T){
+      if(Voronoi){
         if(l.PART > max.obs.req){
           if(noise.reduction == 'mean' | noise.reduction == 'off'){
             PART[ max.obs.req.rows , {
@@ -185,7 +186,7 @@ NNS.part = function(x, y, Voronoi = FALSE, type = NULL, order = NULL, max.obs.re
     }
 
 
-    if(Voronoi == T){
+    if(Voronoi){
       points(RP$x, RP$y, pch = 15, lwd = 2, col = 'red')
       title(main = paste0("NNS Order = ", i), cex.main = 2)
     }
@@ -214,6 +215,7 @@ NNS.part = function(x, y, Voronoi = FALSE, type = NULL, order = NULL, max.obs.re
       if(min.obs.stop && (min(PART$counts) <= 2 * max.obs.req) && i >= 1) break
       max.obs.req.rows = PART[counts >= 2 * max.obs.req, which = TRUE]
       old.max.obs.req.rows = PART[old.counts >= 2 * max.obs.req, which = TRUE]
+      # Stop if diminishing returns
       if(max.obs.req > 0 & length(max.obs.req.rows) < length(old.max.obs.req.rows)) break
 
       if(noise.reduction == 'mean' | noise.reduction == 'off'){
@@ -266,7 +268,7 @@ NNS.part = function(x, y, Voronoi = FALSE, type = NULL, order = NULL, max.obs.re
     }
 
 
-    if(Voronoi == T){
+    if(Voronoi){
       abline(v = RP$x, lty = 3)
       points(RP$x, RP$y, pch = 15, lwd = 2, col = 'red')
       title(main = paste0("NNS Order = ", i), cex.main = 2)
