@@ -1,8 +1,12 @@
 ## ----setup, include=FALSE------------------------------------------------
 knitr::opts_chunk$set(echo = TRUE)
+
+## ----setup2,message=FALSE------------------------------------------------
 require(NNS)
 require(knitr)
 require(rgl)
+require(data.table)
+require(plyr)
 
 ## ----linear,fig.width=5,fig.height=3,fig.align = "center"----------------
 x = seq(0, 3, .01) ; y = 2 * x
